==> arla_0.23.orig.tar.gz: arla-0.23/xfs/aix/xfs/xfs_node.h <==
/*
 * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/* $Id: xfs_node.h,v 1.2 1998/12/22 13:16:09 lha Exp $ */

#ifndef _xfs_xnode_h
#define _xfs_xnode_h

#include <sys/types.h>
#include <sys/time.h>
#include <sys/vnode.h>
#include <sys/vattr.h>

#include <xfs/xfs_attr.h>
#include <xfs/xfs_message.h>

struct xfs_node {
  struct vnode vn;
  struct gnode gn;
  struct vattr attr;
  u_int flags;
  u_int tokens;
  xfs_handle handle;
  pag_t id[MAXRIGHTS];
  u_char rights[MAXRIGHTS];
  u_char anonrights;

  struct xfs_node *next;
};

#define DATA_FROM_VNODE(vp) ((struct vnode *) (vp)->v_data)
#define DATA_FROM_XNODE(xp) DATA_FROM_VNODE(XNODE_TO_VNODE(xp))

#define SET_DATA_FROM_VNODE(vp,d) (vp)->v_data = (caddr_t)(d)
#define SET_DATA_FROM_XNODE(xp,d) SET_DATA_FROM_VNODE(XNODE_TO_VNODE(xp),d)

#define XNODE_TO_VNODE(xp) (&((xp)->vn))
#define VNODE_TO_XNODE(vp) ((struct xfs_node *) vp)

#endif /* _xfs_xnode_h */

==> arla-0.34.4pre2.tar.gz: arla-0.34.4pre2/xfs/aix/xfs/xfs_node.h <==
/*
 * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/* $Id: xfs_node.h,v 1.4 2000/06/11 09:12:52 assar Exp $ */

#ifndef _xfs_xnode_h
#define _xfs_xnode_h

#include <sys/types.h>
#include <sys/time.h>
#include <sys/vnode.h>
#include <sys/vattr.h>

#include <xfs/xfs_attr.h>
#include <xfs/xfs_message.h>

struct xfs_node {
  struct vnode vn;
  struct gnode gn;
  struct vattr attr;
  u_int flags;
  u_int tokens;
  xfs_handle handle;
  xfs_pag_t id[MAXRIGHTS];
  u_char rights[MAXRIGHTS];
  u_char anonrights;

  struct xfs_node *next;
};

#define DATA_FROM_VNODE(vp) ((struct vnode *) (vp)->v_data)
#define DATA_FROM_XNODE(xp) DATA_FROM_VNODE(XNODE_TO_VNODE(xp))

#define SET_DATA_FROM_VNODE(vp,d) (vp)->v_data = (caddr_t)(d)
#define SET_DATA_FROM_XNODE(xp,d) SET_DATA_FROM_VNODE(XNODE_TO_VNODE(xp),d)

#define XNODE_TO_VNODE(xp) (&((xp)->vn))
#define VNODE_TO_XNODE(vp) ((struct xfs_node *) vp)

#endif /* _xfs_xnode_h */
